==> social-component-service-6.5.5-exo-sources.jar: io/meeds/social/link/rest/model/LinkSettingRestEntity.java <==
/**
 * This file is part of the Meeds project (https://meeds.io/).
 *
 * Copyright (C) 2020 - 2023 Meeds Association contact@meeds.io
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

package io.meeds.social.link.rest.model;

import java.util.List;
import java.util.Map;

import io.meeds.social.link.constant.LinkDisplayType;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

@AllArgsConstructor
@NoArgsConstructor
@Data
public class LinkSettingRestEntity {

  private long                 id;

  private String               name;

  private Map<String, String>  header;

  private LinkDisplayType      type;

  private boolean              largeIcon;

  private boolean              showName;

  private boolean              showDescription;

  private String               seeMore;

  private List<LinkRestEntity> links;

}

==> social-component-service-7.0.2-exo-sources.jar: io/meeds/social/link/rest/model/LinkSettingRestEntity.java <==
/**
 * This file is part of the Meeds project (https://meeds.io/).
 *
 * Copyright (C) 2020 - 2023 Meeds Association contact@meeds.io
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

package io.meeds.social.link.rest.model;

import java.util.List;
import java.util.Map;

import io.meeds.social.link.constant.LinkAlignType;
import io.meeds.social.link.constant.LinkDisplayType;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

@AllArgsConstructor
@NoArgsConstructor
@Data
public class LinkSettingRestEntity {

  private long                 id;

  private String               name;

  private Map<String, String>  header;

  private LinkDisplayType      type;

  private LinkAlignType        vAlign;

  private LinkAlignType        hAlign;

  private boolean              largeIcon;

  private int                  iconSize;

  private boolean              showName;

  private boolean              showIcon;

  private boolean              showDescription;

  private String               seeMore;

  private List<LinkRestEntity> links;

}
